Shakespeare
===========

    To be or not to be

Shakespeare answers that very important question. Using Nginx's
[X-Accel](https://www.nginx.com/resources/wiki/start/topics/examples/x-accel/)
capabilities it allows you to mount a auth system on top of your existing
microservicesc without changing microservice code.


Todo
----

- [ ] is user logged in
- [ ] groups and permissions
